[![Downloads](https://pepy.tech/badge/aqua)](https://pepy.tech/project/aqua)

aqua-py
====

A Python 3 compatible SDK for Aqua's Container Security Platform.<br/>
Current Status: Experimental

## Installation
pip install aqua

